@@ -11,8 +11,7 @@ from BeautifulSoup import BeautifulSoup, NavigableString
 
 def hyphenate(html, language='en-us', hyphenator=None, blacklist_tags=(
     'code', 'tt', 'pre', 'head', 'title', 'script', 'style', 'meta', 'object',
-    'embed', 'samp', 'var', 'math', 'select', 'option', 'input', 'textarea',
-    'span',
+    'embed', 'samp', 'var', 'math', 'select', 'option', 'input', 'textarea'
     )):
     """
     Hyphenate a fragement of HTML
@@ -48,7 +47,7 @@ def hyphenate(html, language='en-us', hyphenator=None, blacklist_tags=(
 # Constants
 SOFT_HYPHEN = r'&shy;'
 SPACE = r' '
-STRIP_WHITESPACE = re.compile('\w+', re.MULTILINE|re.UNICODE)
+STRIP_WHITESPACE = re.compile('\w+', re.MULTILINE)
 
 def hyphenate_element(soup, hyphenator, blacklist_tags):
     """
